summaryrefslogtreecommitdiffstats
path: root/kpackage/packageDisplay.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpackage/packageDisplay.h')
-rw-r--r--kpackage/packageDisplay.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/kpackage/packageDisplay.h b/kpackage/packageDisplay.h
index 5631925..c85ff52 100644
--- a/kpackage/packageDisplay.h
+++ b/kpackage/packageDisplay.h
@@ -9,7 +9,7 @@
//
// The file list will be displayed using a tree list.
//
// The widget is mainly a QTabDialog with two tabs: Info and FileList.
// The Info tab is the default one.
*/
@@ -42,10 +42,10 @@
#include "../config.h"
// Qt Headers
-#include <qframe.h>
-#include <qtabbar.h>
-#include <qtabwidget.h>
-#include <qvbox.h>
+#include <tqframe.h>
+#include <tqtabbar.h>
+#include <tqtabwidget.h>
+#include <tqvbox.h>
#include <kpopupmenu.h>
#include <klistview.h>
@@ -60,18 +60,18 @@ class kpFileList : public KListView
public:
- kpFileList(QWidget* parent, packageDisplayWidget* parent2);
+ kpFileList(TQWidget* parent, packageDisplayWidget* parent2);
- QString item2Path(QListViewItem *it);
+ TQString item2Path(TQListViewItem *it);
public slots:
- void openContext(KListView *, QListViewItem *, const QPoint &);
+ void openContext(KListView *, TQListViewItem *, const TQPoint &);
virtual void clear();
- QListViewItem* insert(const QString &cur, const QPixmap &pixmap);
+ TQListViewItem* insert(const TQString &cur, const TQPixmap &pixmap);
private:
@@ -89,7 +89,7 @@ class packageDisplayWidget : public QTabWidget
friend class kpFileList;
///////////// METHODS ------------------------------------------------------
public:
- packageDisplayWidget(QWidget *parent=0);
+ packageDisplayWidget(TQWidget *parent=0);
// Constructor
~packageDisplayWidget();
@@ -113,17 +113,17 @@ private:
// This updates the change log to match that found with the currently
// selected package
- void tabSet(QWidget *);
+ void tabSet(TQWidget *);
// Set display for corresponding tab
///////////// SLOTS --------------------------------------------------------
public slots:
- void tabSelected(QWidget *);
+ void tabSelected(TQWidget *);
- void openBinding(QListViewItem *);
+ void openBinding(TQListViewItem *);
- void openBindingWith(QListViewItem *);
+ void openBindingWith(TQListViewItem *);
void __openBindingWith();
@@ -137,21 +137,21 @@ public:
private:
- QTabWidget *tabbar;
+ TQTabWidget *tabbar;
// The tab bar
- QVBox *proptab, *fltab, *cltab;
+ TQVBox *proptab, *fltab, *cltab;
- QWidget *curTab;
+ TQWidget *curTab;
// current active tab
kpFileList *fileList;
// This holds the file list (and is used as a page on the tab dialog)
- QTextEdit *changeLog;
+ TQTextEdit *changeLog;
// Holds changelog
- QPixmap tick, cross, question, *blank;
+ TQPixmap tick, cross, question, *blank;
// The pixmaps for the filelist
packagePropertiesWidget *packageProperties;
@@ -9,7 +9,7 @@
// The file list will be displayed using a tree list.
//
-// The widget is mainly a QTabDialog with two tabs: Info and FileList.
+// The widget is mainly a TQTabDialog with two tabs: Info and FileList.
// The Info tab is the default one.
*/